
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '35.3.0',
    'branch_nick': 'release-35-LTS',
    'revision_id': 'f6b86349677cb344f3a3db2c12f0841accc9a5ca',
    'revno': 13148
}
